import { format, isAfter, startOfToday } from 'date-fns'
import { FindProjects } from 'types/graphql'

import { Link, routes } from '@redwoodjs/router'

import AutoCarousel from 'src/components/AutoCarousel/AutoCarousel'
import { calculateLuminance } from 'src/lib/color'

const ProjectsShowcase = ({ projects }: FindProjects) => (
  <div className="flex flex-wrap justify-center gap-2">
    {projects
      .slice()
      .sort((a, b) => (isAfter(new Date(b.date), new Date(a.date)) ? 1 : -1))
      .map((project, i) => (
        <Link key={i} to={routes.project({ id: project.id })}>
          <div className="card card-compact bg-base-100 w-96 h-fit shadow-xl transition-all hover:-translate-y-2 hover:shadow-2xl">
            {project.images.length > 0 && (
              <AutoCarousel images={project.images} />
            )}
            <div className="card-body">
              <div className="card-title overflow-auto">
                <p className="whitespace-nowrap">{project.title}</p>
              </div>
              <div className="line-clamp-5">{project.description}</div>
              <div className="card-actions justify-between">
                <div className="flex gap-2">
                  {isAfter(new Date(project.date), startOfToday()) && (
                    <div className="badge badge-info">planned</div>
                  )}
                  <div className="badge badge-ghost">
                    {format(project.date, 'yyyy-MM-dd')}
                  </div>
                </div>
                <div className="flex flex-wrap gap-2">
                  {project.tags.map((tag, i) => (
                    <div
                      key={i}
                      className="badge whitespace-nowrap"
                      style={{
                        backgroundColor: tag.color,
                        color:
                          calculateLuminance(tag.color) > 0.5
                            ? 'black'
                            : 'white',
                      }}
                    >
                      {tag.tag}
                    </div>
                  ))}
                </div>
              </div>
            </div>
          </div>
        </Link>
      ))}
  </div>
)

export default ProjectsShowcase
