import { useState } from 'react'

import Compressor from '@uppy/compressor'
import Uppy from '@uppy/core'
import type { UploadResult, Meta } from '@uppy/core'
import { Dashboard } from '@uppy/react'
import Tus from '@uppy/tus'

import { isProduction } from '@redwoodjs/api/logger'

import '@uppy/core/dist/style.min.css'
import '@uppy/dashboard/dist/style.min.css'

interface Props {
  onComplete?(result: UploadResult<Meta, Record<string, never>>): void
  width?: string | number
  height?: string | number
  className?: string
  maxFiles?: number
  disabled?: boolean
  hidden?: boolean
}

const apiDomain = isProduction
  ? process.env.API_ADDRESS_PROD
  : process.env.API_ADDRESS_DEV

const Uploader = ({
  onComplete,
  width,
  height,
  className,
  disabled = false,
  hidden = false,
  maxFiles = 1,
}: Props) => {
  const [uppy] = useState(() => {
    const instance = new Uppy({
      restrictions: {
        allowedFileTypes: [
          'image/webp',
          'image/png',
          'image/jpg',
          'image/jpeg',
        ],
        maxNumberOfFiles: maxFiles,
        maxFileSize: 25 * 1024 * 1024,
      },
      onBeforeUpload: (files) => {
        for (const [key, file] of Object.entries(files)) {
          instance.setFileMeta(key, {
            name: new Date().getTime().toString(),
            type: file.type,
            contentType: file.type,
          })
        }

        return true
      },
    })
      .use(Tus, {
        endpoint: `${apiDomain}/files`,
        withCredentials: true,
        removeFingerprintOnSuccess: true,
      })
      .use(Compressor, {
        mimeType: 'image/webp',
      })

    return instance.on('complete', onComplete)
  })

  return (
    <Dashboard
      uppy={uppy}
      proudlyDisplayPoweredByUppy={false}
      width={width}
      height={height}
      disabled={disabled}
      hidden={hidden}
      className={className}
    />
  )
}

export default Uploader
